==> acornlib-1.21.1-r7-sources.jar: net/acoyt/acornlib/impl/util/PlushUtils.java <==
package net.acoyt.acornlib.impl.util;

import net.acoyt.acornlib.api.ALib;
import net.acoyt.acornlib.impl.init.AcornBlocks;
import net.acoyt.acornlib.impl.init.AcornSounds;
import net.acoyt.acornlib.impl.init.AcornTags;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_7923;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.atomic.AtomicReference;

public class PlushUtils {
    // Plush Block from ItemStack
    public static class_2248 getPlushBlock(class_1799 stack) {
        AtomicReference<class_2248> block = new AtomicReference<>(class_2246.field_10161);

        if (stack.method_31574(AcornBlocks.ACO_PLUSH.method_8389())) {
            block.set(AcornBlocks.ACO_PLUSH);
        }

        if (stack.method_31574(AcornBlocks.FESTIVE_ACO_PLUSH.method_8389())) {
            block.set(AcornBlocks.FESTIVE_ACO_PLUSH);
        }

        if (stack.method_31574(AcornBlocks.CLOWN_ACO_PLUSH.method_8389())) {
            block.set(AcornBlocks.CLOWN_ACO_PLUSH);
        }

        if (stack.method_31574(AcornBlocks.MYTHORICAL_PLUSH.method_8389())) {
            block.set(AcornBlocks.MYTHORICAL_PLUSH);
        }

        if (stack.method_31574(AcornBlocks.GNARP_PLUSH.method_8389())) {
            block.set(AcornBlocks.GNARP_PLUSH);
        }

        if (stack.method_31574(AcornBlocks.KIO_PLUSH.method_8389())) {
            block.set(AcornBlocks.KIO_PLUSH);
        }

        if (stack.method_31574(AcornBlocks.TOAST_PLUSH.method_8389())) {
            block.set(AcornBlocks.TOAST_PLUSH);
        }

        if (stack.method_31574(AcornBlocks.CHEM_PLUSH.method_8389())) {
            block.set(AcornBlocks.CHEM_PLUSH);
        }

        if (stack.method_31573(AcornTags.PLUSHIES)) {
            class_2960 itemId = class_7923.field_41178.method_10221(stack.method_7909());
            return class_7923.field_41175.method_10223(itemId); // Gets the block with the ID of the item, which *should* work.
        }

        ALib.plushies.forEach(plushData -> {
            if (plushData.block().method_8389().equals(stack.method_7909())) {
                block.set(plushData.block());
            }
        });

        return block.get();
    }

    // Plush Item from Block
    public static class_1792 getPlushItem(class_2248 block) {
        AtomicReference<class_1792> item = new AtomicReference<>(class_1802.field_8162);
        if (block == AcornBlocks.ACO_PLUSH) {
            item.set(AcornBlocks.ACO_PLUSH.method_8389());
        }

        if (block == AcornBlocks.FESTIVE_ACO_PLUSH) {
            item.set(AcornBlocks.FESTIVE_ACO_PLUSH.method_8389());
        }

        if (block == AcornBlocks.CLOWN_ACO_PLUSH) {
            item.set(AcornBlocks.CLOWN_ACO_PLUSH.method_8389());
        }

        if (block == AcornBlocks.MYTHORICAL_PLUSH) {
            item.set(AcornBlocks.MYTHORICAL_PLUSH.method_8389());
        }

        if (block == AcornBlocks.GNARP_PLUSH) {
            item.set(AcornBlocks.GNARP_PLUSH.method_8389());
        }

        if (block == AcornBlocks.KIO_PLUSH) {
            item.set(AcornBlocks.KIO_PLUSH.method_8389());
        }

        if (block == AcornBlocks.TOAST_PLUSH) {
            item.set(AcornBlocks.TOAST_PLUSH.method_8389());
        }

        if (block == AcornBlocks.CHEM_PLUSH) {
            item.set(AcornBlocks.CHEM_PLUSH.method_8389());
        }

        ALib.plushies.forEach(plushData -> {
            if (block == plushData.block()) {
                item.set(plushData.block().method_8389());
            }
        });

        return block.method_9564().method_26164(AcornTags.PLUSH_BLOCKS) ? block.method_8389() : item.get(); // Gets the block as an item, if it's a plushie.
    }

    // Plush Sound from BlockState
    public static class_3414 getPlushSound(class_2680 state) {
        Map<class_2248, class_3414> sounds = new HashMap<>();

        sounds.put(AcornBlocks.ACO_PLUSH, AcornSounds.ACO_PLUSH_HONK);
        sounds.put(AcornBlocks.FESTIVE_ACO_PLUSH, AcornSounds.FESTIVE_ACO_PLUSH_HONK);
        sounds.put(AcornBlocks.CLOWN_ACO_PLUSH, AcornSounds.CLOWN_ACO_PLUSH_HONK);
        sounds.put(AcornBlocks.MYTHORICAL_PLUSH, AcornSounds.MYTH_PLUSH_HONK);
        sounds.put(AcornBlocks.GNARP_PLUSH, AcornSounds.HOLY_GNARP);
        sounds.put(AcornBlocks.KIO_PLUSH, AcornSounds.FOUR_KIO);
        sounds.put(AcornBlocks.TOAST_PLUSH, AcornSounds.MREW);
        sounds.put(AcornBlocks.CHEM_PLUSH, AcornSounds.GOOBER);

        ALib.plushies.forEach(plushData -> sounds.put(plushData.block(), plushData.soundEvent()));

        return sounds.getOrDefault(state.method_26204(), class_3417.field_14628);
    }

    // Plush Sound from ItemStack
    public static class_3414 getPlushSound(class_1799 stack) {
        class_3414 squoze = class_3417.field_14628;

        class_2960 itemId = class_7923.field_41178.method_10221(stack.method_7909());
        class_2680 state = class_7923.field_41175.method_10223(itemId).method_9564();
        return getPlushSound(state);

//        if (stack.isOf(AcornBlocks.ACO_PLUSH.asItem())) {
//            squoze = AcornSounds.ACO_PLUSH_HONK;
//        }
//
//        if (stack.isOf(AcornBlocks.FESTIVE_ACO_PLUSH.asItem())) {
//            squoze = AcornSounds.FESTIVE_ACO_PLUSH_HONK;
//        }
//
//        if (stack.isOf(AcornBlocks.CLOWN_ACO_PLUSH.asItem())) {
//            squoze = AcornSounds.CLOWN_ACO_PLUSH_HONK;
//        }
//
//        if (stack.isOf(AcornBlocks.MYTHORICAL_PLUSH.asItem())) {
//            squoze = AcornSounds.MYTH_PLUSH_HONK;
//        }
//
//        if (stack.isOf(AcornBlocks.GNARP_PLUSH.asItem())) {
//            squoze = AcornSounds.HOLY_GNARP;
//        }
//
//        if (stack.isOf(AcornBlocks.KIO_PLUSH.asItem())) {
//            squoze = AcornSounds.FOUR_KIO;
//        }
//
//        if (stack.isOf(AcornBlocks.TOAST_PLUSH.asItem())) {
//            squoze = AcornSounds.MREW;
//        }
//
//        return squoze;
    }

    // Plush Stack from Block
    public static class_1799 getPlushStack(class_2248 block) {
        AtomicReference<class_1799> stack = new AtomicReference<>(class_1802.field_8162.method_7854());

//        if (block == AcornBlocks.ACO_PLUSH) {
//            stack = AcornBlocks.ACO_PLUSH.asItem().getDefaultStack();
//        }
//
//        if (block == AcornBlocks.FESTIVE_ACO_PLUSH) {
//            stack = AcornBlocks.FESTIVE_ACO_PLUSH.asItem().getDefaultStack();
//        }
//
//        if (block == AcornBlocks.CLOWN_ACO_PLUSH) {
//            stack = AcornBlocks.CLOWN_ACO_PLUSH.asItem().getDefaultStack();
//        }
//
//        if (block == AcornBlocks.MYTHORICAL_PLUSH) {
//            stack = AcornBlocks.MYTHORICAL_PLUSH.asItem().getDefaultStack();
//        }
//
//        if (block == AcornBlocks.GNARP_PLUSH) {
//            stack = AcornBlocks.GNARP_PLUSH.asItem().getDefaultStack();
//        }
//
//        if (block == AcornBlocks.KIO_PLUSH) {
//            stack = AcornBlocks.KIO_PLUSH.asItem().getDefaultStack();
//        }
//
//        if (block == AcornBlocks.TOAST_PLUSH) {
//            stack = AcornBlocks.TOAST_PLUSH.asItem().getDefaultStack();
//        }
//
        // Checks if it's a plush block
        if (block.method_9564().method_26164(AcornTags.PLUSH_BLOCKS)) {
            class_2960 blockId = class_7923.field_41175.method_10221(block);
            return class_7923.field_41178.method_10223(blockId).method_7854(); // Gets the item with the ID of the block, which *should* work.
        }

        ALib.plushies.forEach(plushData -> {
            if (block == plushData.block()) {
                class_2960 blockId = class_7923.field_41175.method_10221(block);
                stack.set(class_7923.field_41178.method_10223(blockId).method_7854());
            }
        });

        return stack.get();
    }
}

==> acornlib-1.21.5-r19-sources.jar: net/acoyt/acornlib/impl/util/PlushUtils.java <==
package net.acoyt.acornlib.impl.util;

import net.acoyt.acornlib.impl.index.AcornBlocks;
import net.acoyt.acornlib.impl.index.AcornSounds;
import net.acoyt.acornlib.impl.index.AcornTags;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_7923;
import java.util.HashMap;
import java.util.Map;

@SuppressWarnings("unused")
public class PlushUtils {
    // Plush Block from ItemStack
    public static class_2248 getPlushBlock(class_1799 stack) {
        class_2248 block = class_2246.field_10161;

        if (stack.method_31574(AcornBlocks.ACO_PLUSH.method_8389())) {
            block = AcornBlocks.ACO_PLUSH;
        }

        if (stack.method_31574(AcornBlocks.FESTIVE_ACO_PLUSH.method_8389())) {
            block = AcornBlocks.FESTIVE_ACO_PLUSH;
        }

        if (stack.method_31574(AcornBlocks.CLOWN_ACO_PLUSH.method_8389())) {
            block = AcornBlocks.CLOWN_ACO_PLUSH;
        }

        if (stack.method_31574(AcornBlocks.MYTHORICAL_PLUSH.method_8389())) {
            block = AcornBlocks.MYTHORICAL_PLUSH;
        }

        if (stack.method_31574(AcornBlocks.GNARP_PLUSH.method_8389())) {
            block = AcornBlocks.GNARP_PLUSH;
        }

        if (stack.method_31574(AcornBlocks.KIO_PLUSH.method_8389())) {
            block = AcornBlocks.KIO_PLUSH;
        }

        if (stack.method_31574(AcornBlocks.TOAST_PLUSH.method_8389())) {
            block = AcornBlocks.TOAST_PLUSH;
        }

        if (stack.method_31574(AcornBlocks.CHEM_PLUSH.method_8389())) {
            block = AcornBlocks.CHEM_PLUSH;
        }

        if (stack.method_31573(AcornTags.PLUSHIES)) {
            class_2960 itemId = class_7923.field_41178.method_10221(stack.method_7909());
            return class_7923.field_41175.method_63535(itemId); // Gets the block with the ID of the item, which *should* work.
        }

        return block;
    }

    // Plush Item from Block
    public static class_1792 getPlushItem(class_2248 block) {
        class_1792 item = class_1802.field_8162;
        if (block == AcornBlocks.ACO_PLUSH) {
            item = AcornBlocks.ACO_PLUSH.method_8389();
        }

        if (block == AcornBlocks.FESTIVE_ACO_PLUSH) {
            item = AcornBlocks.FESTIVE_ACO_PLUSH.method_8389();
        }

        if (block == AcornBlocks.CLOWN_ACO_PLUSH) {
            item = AcornBlocks.CLOWN_ACO_PLUSH.method_8389();
        }

        if (block == AcornBlocks.MYTHORICAL_PLUSH) {
            item = AcornBlocks.MYTHORICAL_PLUSH.method_8389();
        }

        if (block == AcornBlocks.GNARP_PLUSH) {
            item = AcornBlocks.GNARP_PLUSH.method_8389();
        }

        if (block == AcornBlocks.KIO_PLUSH) {
            item = AcornBlocks.KIO_PLUSH.method_8389();
        }

        if (block == AcornBlocks.TOAST_PLUSH) {
            item = AcornBlocks.TOAST_PLUSH.method_8389();
        }

        if (block == AcornBlocks.CHEM_PLUSH) {
            item = AcornBlocks.CHEM_PLUSH.method_8389();
        }

        return block.method_9564().method_26164(AcornTags.PLUSH_BLOCKS) ? block.method_8389() : class_1802.field_8162; // Gets the block as an item, if it's a plushie.
    }

    // Plush Sound from BlockState
    public static class_3414 getPlushSound(class_2680 state) {
        Map<class_2248, class_3414> sounds = new HashMap<>();

        sounds.put(AcornBlocks.ACO_PLUSH, AcornSounds.ACO_PLUSH_HONK);
        sounds.put(AcornBlocks.FESTIVE_ACO_PLUSH, AcornSounds.FESTIVE_ACO_PLUSH_HONK);
        sounds.put(AcornBlocks.CLOWN_ACO_PLUSH, AcornSounds.CLOWN_ACO_PLUSH_HONK);
        sounds.put(AcornBlocks.MYTHORICAL_PLUSH, AcornSounds.MYTH_PLUSH_HONK);
        sounds.put(AcornBlocks.GNARP_PLUSH, AcornSounds.HOLY_GNARP);
        sounds.put(AcornBlocks.KIO_PLUSH, AcornSounds.FOUR_KIO);
        sounds.put(AcornBlocks.TOAST_PLUSH, AcornSounds.MREW);
        sounds.put(AcornBlocks.CHEM_PLUSH, AcornSounds.GOOBER);

        return sounds.getOrDefault(state.method_26204(), class_3417.field_14628);
    }

    // Plush Sound from ItemStack
    public static class_3414 getPlushSound(class_1799 stack) {
        class_3414 squoze = class_3417.field_14628;

        class_2960 itemId = class_7923.field_41178.method_10221(stack.method_7909());
        class_2680 state = class_7923.field_41175.method_63535(itemId).method_9564();
        return getPlushSound(state);

//        if (stack.isOf(AcornBlocks.ACO_PLUSH.asItem())) {
//            squoze = AcornSounds.ACO_PLUSH_HONK;
//        }
//
//        if (stack.isOf(AcornBlocks.FESTIVE_ACO_PLUSH.asItem())) {
//            squoze = AcornSounds.FESTIVE_ACO_PLUSH_HONK;
//        }
//
//        if (stack.isOf(AcornBlocks.CLOWN_ACO_PLUSH.asItem())) {
//            squoze = AcornSounds.CLOWN_ACO_PLUSH_HONK;
//        }
//
//        if (stack.isOf(AcornBlocks.MYTHORICAL_PLUSH.asItem())) {
//            squoze = AcornSounds.MYTH_PLUSH_HONK;
//        }
//
//        if (stack.isOf(AcornBlocks.GNARP_PLUSH.asItem())) {
//            squoze = AcornSounds.HOLY_GNARP;
//        }
//
//        if (stack.isOf(AcornBlocks.KIO_PLUSH.asItem())) {
//            squoze = AcornSounds.FOUR_KIO;
//        }
//
//        if (stack.isOf(AcornBlocks.TOAST_PLUSH.asItem())) {
//            squoze = AcornSounds.MREW;
//        }
//
//        return squoze;
    }

    // Plush Stack from Block
    public static class_1799 getPlushStack(class_2248 block) {
        class_1799 stack = class_1802.field_8162.method_7854();

//        if (block == AcornBlocks.ACO_PLUSH) {
//            stack = AcornBlocks.ACO_PLUSH.asItem().getDefaultStack();
//        }
//
//        if (block == AcornBlocks.FESTIVE_ACO_PLUSH) {
//            stack = AcornBlocks.FESTIVE_ACO_PLUSH.asItem().getDefaultStack();
//        }
//
//        if (block == AcornBlocks.CLOWN_ACO_PLUSH) {
//            stack = AcornBlocks.CLOWN_ACO_PLUSH.asItem().getDefaultStack();
//        }
//
//        if (block == AcornBlocks.MYTHORICAL_PLUSH) {
//            stack = AcornBlocks.MYTHORICAL_PLUSH.asItem().getDefaultStack();
//        }
//
//        if (block == AcornBlocks.GNARP_PLUSH) {
//            stack = AcornBlocks.GNARP_PLUSH.asItem().getDefaultStack();
//        }
//
//        if (block == AcornBlocks.KIO_PLUSH) {
//            stack = AcornBlocks.KIO_PLUSH.asItem().getDefaultStack();
//        }
//
//        if (block == AcornBlocks.TOAST_PLUSH) {
//            stack = AcornBlocks.TOAST_PLUSH.asItem().getDefaultStack();
//        }
//
        if (block.method_9564().method_26164(AcornTags.PLUSH_BLOCKS)) {
            class_2960 blockId = class_7923.field_41175.method_10221(block);
            return class_7923.field_41178.method_63535(blockId).method_7854(); // Gets the item with the ID of the block, which *should* work.
        }

        return stack;
    }
}
